import { CompleteAttachment } from "./AttachmentTypes";
import { ReadonlyJSONObject, ReadonlyJSONValue } from "assistant-stream/utils";
export type MessageRole = ThreadMessage["role"];
export type TextMessagePart = {
    readonly type: "text";
    readonly text: string;
};
export type ReasoningMessagePart = {
    readonly type: "reasoning";
    readonly text: string;
};
export type SourceMessagePart = {
    readonly type: "source";
    readonly sourceType: "url";
    readonly id: string;
    readonly url: string;
    readonly title?: string;
};
export type ImageMessagePart = {
    readonly type: "image";
    readonly image: string;
};
export type FileMessagePart = {
    readonly type: "file";
    readonly data: string;
    readonly mimeType: string;
};
export type Unstable_AudioMessagePart = {
    readonly type: "audio";
    readonly audio: {
        readonly data: string;
        readonly format: "mp3" | "wav";
    };
};
export type ToolCallMessagePart<TArgs = ReadonlyJSONObject, TResult = unknown> = {
    readonly type: "tool-call";
    readonly toolCallId: string;
    readonly toolName: string;
    readonly args: TArgs;
    readonly result?: TResult | undefined;
    readonly isError?: boolean | undefined;
    readonly argsText: string;
    readonly artifact?: unknown;
};
export type ThreadUserMessagePart = TextMessagePart | ImageMessagePart | FileMessagePart | Unstable_AudioMessagePart;
export type ThreadAssistantMessagePart = TextMessagePart | ReasoningMessagePart | ToolCallMessagePart | SourceMessagePart | FileMessagePart;
type MessageCommonProps = {
    readonly id: string;
    readonly createdAt: Date;
};
export type ThreadStep = {
    readonly messageId?: string;
    readonly usage?: {
        readonly promptTokens: number;
        readonly completionTokens: number;
    } | undefined;
};
export type MessagePartStatus = {
    readonly type: "running";
} | {
    readonly type: "complete";
} | {
    readonly type: "incomplete";
    readonly reason: "cancelled" | "length" | "content-filter" | "other" | "error";
    readonly error?: unknown;
};
export type ToolCallMessagePartStatus = {
    readonly type: "requires-action";
    readonly reason: "tool-calls";
} | MessagePartStatus;
export type MessageStatus = {
    readonly type: "running";
} | {
    readonly type: "requires-action";
    readonly reason: "tool-calls";
} | {
    readonly type: "complete";
    readonly reason: "stop" | "unknown";
} | {
    readonly type: "incomplete";
    readonly reason: "cancelled" | "tool-calls" | "length" | "content-filter" | "other" | "error";
    readonly error?: ReadonlyJSONValue;
};
export type ThreadSystemMessage = MessageCommonProps & {
    readonly role: "system";
    readonly content: readonly [TextMessagePart];
    readonly metadata: {
        readonly custom: Record<string, unknown>;
    };
};
export type ThreadUserMessage = MessageCommonProps & {
    readonly role: "user";
    readonly content: readonly ThreadUserMessagePart[];
    readonly attachments: readonly CompleteAttachment[];
    readonly metadata: {
        readonly custom: Record<string, unknown>;
    };
};
export type ThreadAssistantMessage = MessageCommonProps & {
    readonly role: "assistant";
    readonly content: readonly ThreadAssistantMessagePart[];
    readonly status: MessageStatus;
    readonly metadata: {
        readonly unstable_state: ReadonlyJSONValue;
        readonly unstable_annotations: readonly ReadonlyJSONValue[];
        readonly unstable_data: readonly ReadonlyJSONValue[];
        readonly steps: readonly ThreadStep[];
        readonly custom: Record<string, unknown>;
    };
};
export type RunConfig = {
    readonly custom?: Record<string, unknown>;
};
export type AppendMessage = Omit<ThreadMessage, "id"> & {
    parentId: string | null;
    /** The ID of the message that was edited or undefined. */
    sourceId: string | null;
    runConfig: RunConfig | undefined;
    startRun?: boolean | undefined;
};
type BaseThreadMessage = {
    readonly status?: ThreadAssistantMessage["status"];
    readonly metadata: {
        readonly unstable_state?: ReadonlyJSONValue;
        readonly unstable_annotations?: readonly ReadonlyJSONValue[];
        readonly unstable_data?: readonly ReadonlyJSONValue[];
        readonly steps?: readonly ThreadStep[];
        readonly custom: Record<string, unknown>;
    };
    readonly attachments?: ThreadUserMessage["attachments"];
};
export type ThreadMessage = BaseThreadMessage & (ThreadSystemMessage | ThreadUserMessage | ThreadAssistantMessage);
export {};
//# sourceMappingURL=AssistantTypes.d.ts.map